===============================
fapistrano
===============================

.. image:: https://img.shields.io/pypi/v/fapistrano.svg
        :target: https://pypi.python.org/pypi/fapistrano

.. image:: https://img.shields.io/travis/liwushuo/fapistrano.svg
        :target: https://travis-ci.org/liwushuo/fapistrano

.. image:: https://readthedocs.org/projects/fapistrano/badge/?version=latest
        :target: https://readthedocs.org/projects/fapistrano/?badge=latest
        :alt: Documentation Status


A remote server automation and deployment tool.

* Free software: MIT license
* Documentation: https://pythonhosted.org/fapistrano .

Features
--------

* well-organized release/rollback flow
* full-customized deploy.yml
* writing plugins is easily
